==> cpes6-project-1.0.12.tgz: package/src/request.js <==
/**
 * Created with WebStorm.
 * @author: jozhua@live.cn
 * @date: 2017/7/18
 * To change this template use File | Settings | File Templates.
 */
import cp from './els';
import Loader from './loader';

function serialize(params, obj, traditional, scope) {
    let type, isarray, array = cp.isArray(obj), hash = cp.isObject(obj);
    cp.each(obj, function (key, value) {
        type = typeof value;
        isarray = cp.isArray(value);
        if (scope) key = traditional ? scope : scope + '[' + (hash || type == 'object' || isarray ? key : '') + ']'
        if (!scope && array) params.add(value.name, value.value)
        // recurse into nested objects
        else if (isarray || (!traditional && type == "object")) serialize(params, value, traditional, key)
        else params.add(key, value)
    })
}
function Request(config) {
    this.config = config;
}
Request.prototype.ajax = function (url, setting, func) {
    if (cp.isFunction(setting)) {
        func = setting;
        setting = {};
    }
    setting = setting || {};
    var self = this, xhr = new window.XMLHttpRequest(), headers = {}, empty = function () {
    }, setHeader = function (name, value) {
        headers[name.toLowerCase()] = [name, value]
    }, nativeSetHeader = xhr.setRequestHeader, blankRE = /^\s*$/, ajax = function () {
        setTimeout(() => {
            loader.close();
            typeof func == 'function' && func.apply(self, arguments)
        }, 200)
    }, loader = new Loader(this.config), abortTimeout;
    setting.url = url;
    this.serializeData(setting);
    if (setting.contentType || (setting.contentType !== false && setting.data && setting.type.toUpperCase() != 'GET')) setHeader('Content-Type', setting.contentType || 'application/x-www-form-urlencoded')
    setHeader('X-Requested-With', 'XMLHttpRequest');
    setHeader('Accept', 'application/json');
    xhr.onreadystatechange = function () {
        if (xhr.readyState == 4) {
            xhr.onreadystatechange = empty;
            clearTimeout(abortTimeout);
            var result, error = false;
            if ((xhr.status >= 200 && xhr.status < 300) || xhr.status == 304) {
                result = xhr.responseText;
                try {
                    result = blankRE.test(result) ? null : JSON.parse(result);
                } catch (e) {
                    error = e
                }
                if (error) return ajax('parsererror', '', xhr);
                else ajax(0, result, xhr)
            } else {
                ajax(xhr.status ? 'error' : 'abort', xhr.statusText || null, xhr)
            }
        }
    };
    xhr.open(setting.type || 'GET', setting.url, true);
    for (var name in headers) nativeSetHeader.apply(xhr, headers[name]);
    loader.open();
    setTimeout(function () {
        xhr.send(setting.data ? setting.data : null);
        if (setting.timeout > 0) abortTimeout = setTimeout(function () {
            xhr.onreadystatechange = empty;
            xhr.abort();
            ajax("timeout", '', xhr, setting)
        }, setting.timeout);
    }, 50);
}
Request.prototype.param = function (obj, traditional) {
    let params = [];
    params.add = function (key, value) {
        if (typeof value == 'function') value = value();
        if (value == null) value = "";
        this.push(escape(key) + '=' + escape(value))
    };
    serialize(params, obj, traditional)
    return params.join('&').replace(/%20/g, '+')
}
Request.prototype.serializeData = function (options) {
    if (options.data && typeof options.data != "string")
        options.data = this.param(options.data, options.traditional)
    if (options.data && (!options.type || options.type.toUpperCase() == 'GET')) {
        if (options.url) options.url = (options.url + '&' + options.data).replace(/[&?]{1,2}/, '?');
        options.data = undefined
    }
};
Request.prototype.get = function (url, data, func) {
    if (cp.isFunction(data)) {
        func = data;
        data = undefined;
    }
    return this.ajax(url, {data: data, type: 'GET'}, func)
}
Request.prototype.post = function (url, data, func) {
    if (cp.isFunction(data)) {
        func = data;
        data = undefined
    }
    return this.ajax(url, {data: data, type: 'POST'}, func)
}
export default Request;

==> cpes6-project-1.1.8.tgz: package/src/request.js <==
/**
 * Created with WebStorm.
 * @author: jozhua@live.cn
 * @date: 2017/7/18
 * To change this template use File | Settings | File Templates.
 */
import cp from './els';
import Loader from './loader';

function serialize(params, obj, traditional, scope) {
    let type, isarray, array = cp.isArray(obj), hash = cp.isObject(obj);
    cp.each(obj, function (key, value) {
        type = typeof value;
        isarray = cp.isArray(value);
        if (scope) key = traditional ? scope : scope + '[' + (hash || type == 'object' || isarray ? key : '') + ']'
        if (!scope && array) params.add(value.name, value.value)
        // recurse into nested objects
        else if (isarray || (!traditional && type == "object")) serialize(params, value, traditional, key)
        else params.add(key, value)
    })
}
function Request(config) {
    this.config = config;
}
Request.prototype.ajax = function (url, setting, func) {
    if (cp.isFunction(setting)) {
        func = setting;
        setting = {};
    }
    setting = setting || {};
    var self = this, xhr = new window.XMLHttpRequest(), headers = {}, empty = function () {
    }, setHeader = function (name, value) {
        headers[name.toLowerCase()] = [name, value]
    }, nativeSetHeader = xhr.setRequestHeader, blankRE = /^\s*$/, ajax = function () {
        setTimeout(() => {
            loader.close();
            typeof func == 'function' && func.apply(self, arguments)
        }, 200)
    }, loader = new Loader(this.config), abortTimeout;
    setting.url = url;
    this.serializeData(setting);
    if (setting.contentType || (setting.contentType !== false && setting.data && setting.type.toUpperCase() != 'GET')) setHeader('Content-Type', setting.contentType || 'application/x-www-form-urlencoded')
    setHeader('X-Requested-With', 'XMLHttpRequest');
    setHeader('Accept', 'application/json');
    xhr.onreadystatechange = function () {
        if (xhr.readyState == 4) {
            xhr.onreadystatechange = empty;
            clearTimeout(abortTimeout);
            var result, error = false;
            if ((xhr.status >= 200 && xhr.status < 300) || xhr.status == 304) {
                result = xhr.responseText;
                try {
                    result = blankRE.test(result) ? null : JSON.parse(result);
                } catch (e) {
                    error = e
                }
                if (error) return ajax('parsererror', '', xhr);
                else ajax(0, result, xhr)
            } else {
                ajax(xhr.status ? 'error' : 'abort', xhr.statusText || null, xhr)
            }
        }
    };
    xhr.open(setting.type || 'GET', setting.url, true);
    for (var name in headers) nativeSetHeader.apply(xhr, headers[name]);
    loader.open();
    setTimeout(function () {
        xhr.send(setting.data ? setting.data : null);
        if (setting.timeout > 0) abortTimeout = setTimeout(function () {
            xhr.onreadystatechange = empty;
            xhr.abort();
            ajax("timeout", '', xhr, setting)
        }, setting.timeout);
    }, 50);
}
Request.prototype.param = function (obj, traditional) {
    let params = [];
    params.add = function (key, value) {
        if (typeof value == 'function') value = value();
        if (value == null) value = "";
        this.push(escape(key) + '=' + escape(value))
    };
    serialize(params, obj, traditional);
    return params.join('&').replace(/%20/g, '+')
}
Request.prototype.serializeData = function (options) {
    if (options.data && typeof options.data != "string")
        options.data = this.param(options.data, options.traditional)
    if (options.data && (!options.type || options.type.toUpperCase() == 'GET')) {
        if (options.url) options.url = (options.url + '&' + options.data).replace(/[&?]{1,2}/, '?');
        options.data = undefined
    }
};
Request.prototype.get = function (url, data, func) {
    if (cp.isFunction(data)) {
        func = data;
        data = undefined;
    }
    return this.ajax(url, {data: data, type: 'GET'}, func)
}
Request.prototype.post = function (url, data, func) {
    if (cp.isFunction(data)) {
        func = data;
        data = undefined
    }
    return this.ajax(url, {data: data, type: 'POST'}, func)
}
export default Request;
